@@ -1,4 +1,4 @@
-""" AWS RDS Module"""
+"""AWS RDS Module"""
 
 # ************************************************************************
 # Copyright 2021 O7 Conseils inc (Philippe Gosselin)
@@ -17,7 +17,6 @@
 #
 # ************************************************************************
 
-
 # --------------------------------
 #
 # --------------------------------
@@ -76,9 +75,7 @@ class Rds(Base):
 
         logger.info(f"load_db_instance: {db_instance_id}")
 
-        response = self.client.describe_db_instances(
-            DBInstanceIdentifier=db_instance_id
-        )
+        response = self.client.describe_db_instances(DBInstanceIdentifier=db_instance_id)
         self.db_instance = response["DBInstances"][0]
 
         return self
@@ -178,6 +175,9 @@ class Rds(Base):
         print(f'DB Name: {self.db_instance.get("DBName", "")}')
         print(f'Multi-AZ: {self.db_instance.get("MultiAZ", "")}')
 
+        print()
+        print(f'Endpoint: {self.db_instance.get("Endpoint", {}).get("Address", "")}')
+        print(f'Port: {self.db_instance.get("Endpoint", {}).get("Port", "")}')
         print()
         print(f'CA Certificate: {self.db_instance.get("CACertificateIdentifier","na")}')
 
@@ -274,7 +274,6 @@ def menu(**kwargs):
 #
 # *************************************************
 if __name__ == "__main__":
-
     logging.basicConfig(
         level=logging.INFO, format="[%(levelname)-5.5s] [%(name)s] %(message)s"
     )
